@@ -27,36 +27,51 @@ gg_color <- function (n) {
 #' @note With this function we can identify if the data is balanced or not, according to the variable to be predicted.
 #'
 #' @import ggplot2
-#'
+#' @importFrom rlang .data
 #' @export
 #'
 #' @examples
 #'
 #' prediction.variable.balance(iris,"Species")
 #'
-prediction.variable.balance <- function(data, predict.variable, ylab = "Number of individuals",
-                                         xlab = "", main = paste("Variable Distribution",predict.variable), col = NA) {
-  if(missing(predict.variable) | !(predict.variable %in% colnames(data))){
-    stop("predict.variable must be entered and be part of the table columns", call. = FALSE )
+prediction.variable.balance <- function(
+    data, predict.variable,
+    ylab = "Number of individuals",
+    xlab = "",
+    main = paste("Variable Distribution", predict.variable),
+    col = NA
+) {
+
+  if (missing(predict.variable) || !(predict.variable %in% colnames(data))) {
+    stop("predict.variable must be entered and be part of the table columns", call. = FALSE)
   }
-  if(is.character(data[,predict.variable]) | is.factor(data[,predict.variable])){
-    if(length(col) == 0 || is.na(col)){
-      col <- gg_color(length(unique(data[,predict.variable])))
-    }else{
-      col <- rep(col,length(unique(data[,predict.variable])))
+
+  if (is.character(data[[predict.variable]]) || is.factor(data[[predict.variable]])) {
+
+    if (length(col) == 0 || all(is.na(col))) {
+      col <- gg_color(length(unique(data[[predict.variable]])))
+    } else {
+      col <- rep(col, length(unique(data[[predict.variable]])))
     }
-    ggplot(data = data, mapping = aes_string(x = predict.variable, fill = predict.variable)) +
-      geom_bar() +
-      scale_fill_manual(values = col, name = predict.variable) +
-      labs(x = xlab, y = ylab, title = main) +
-      theme_minimal() +
-      theme(legend.position = "bottom")
-  }else{
-    stop("The variable to predict must be of type factor or character", call. = FALSE )
+
+    ggplot2::ggplot(
+      data = data,
+      mapping = ggplot2::aes(
+        x = .data[[predict.variable]],
+        fill = .data[[predict.variable]]
+      )
+    ) +
+      ggplot2::geom_bar() +
+      ggplot2::scale_fill_manual(values = col, name = predict.variable) +
+      ggplot2::labs(x = xlab, y = ylab, title = main) +
+      ggplot2::theme_minimal() +
+      ggplot2::theme(legend.position = "bottom")
+
+  } else {
+    stop("The variable to predict must be of type factor or character", call. = FALSE)
   }
 }
 
-
 #' numerical.predictive.power
 #'
 #' @description Function that graphs the density of individuals and shows their category according to a numerical variable.
@@ -76,45 +91,60 @@ prediction.variable.balance <- function(data, predict.variable, ylab = "Number o
 #' @note With this function we can analyze the predictive power of a numerical variable.
 #'
 #' @import ggplot2
-#'
+#' @importFrom rlang .data
 #' @export
 #'
 #' @examples
 #'
 #' numerical.predictive.power(iris,"Species","Sepal.Length")
 #'
-numerical.predictive.power <- function(data, predict.variable, variable.to.compare, ylab = "",
-                                      xlab = "", main = paste("Variable Density", variable.to.compare, 'according to', predict.variable), col = NA){
+numerical.predictive.power <- function(
+    data, predict.variable, variable.to.compare,
+    ylab = "",
+    xlab = "",
+    main = paste("Variable Density", variable.to.compare, "according to", predict.variable),
+    col = NA
+) {
 
-  if(missing(predict.variable) | !(predict.variable %in% colnames(data))){
-    stop("predict.variable must be entered and be part of the table columns", call. = FALSE )
-  }
-  if(missing(variable.to.compare) | !(variable.to.compare %in% colnames(data)) | !is.numeric(data[,variable.to.compare])){
-    stop("variable.to.compare must be entered and be part of the numeric columns of the table", call. = FALSE )
+  if (missing(predict.variable) || !(predict.variable %in% colnames(data))) {
+    stop("predict.variable must be entered and be part of the table columns", call. = FALSE)
   }
 
-  if(is.character(data[,predict.variable]) | is.factor(data[,predict.variable])){
-    if(length(col) == 0 || is.na(col)){
-      col <- gg_color(length(unique(data[,predict.variable])))
-    }else{
-      col <- rep(col,length(unique(data[,predict.variable])))
+  if (missing(variable.to.compare) || !(variable.to.compare %in% colnames(data)) ||
+      !is.numeric(data[[variable.to.compare]])) {
+    stop("variable.to.compare must be entered and be part of the numeric columns of the table", call. = FALSE)
+  }
+
+  if (is.character(data[[predict.variable]]) || is.factor(data[[predict.variable]])) {
+
+    if (length(col) == 0 || all(is.na(col))) {
+      col <- gg_color(length(unique(data[[predict.variable]])))
+    } else {
+      col <- rep(col, length(unique(data[[predict.variable]])))
     }
 
-    ggplot(data = data, aes_string(variable.to.compare, fill = predict.variable)) +
-      geom_density(alpha = .7, color = NA) +
-      scale_fill_manual(values = col) +
-      labs(title = main , y = ylab, x = xlab ,fill = predict.variable) +
-      theme_minimal() +
-      theme(legend.position = 'bottom',
-            legend.title = element_blank(),
-            text = element_text(size = 15))
+    ggplot2::ggplot(
+      data = data,
+      mapping = ggplot2::aes(
+        x = .data[[variable.to.compare]],
+        fill = .data[[predict.variable]]
+      )
+    ) +
+      ggplot2::geom_density(alpha = 0.7, color = NA) +
+      ggplot2::scale_fill_manual(values = col) +
+      ggplot2::labs(title = main, y = ylab, x = xlab, fill = predict.variable) +
+      ggplot2::theme_minimal() +
+      ggplot2::theme(
+        legend.position = "bottom",
+        legend.title = ggplot2::element_blank(),
+        text = ggplot2::element_text(size = 15)
+      )
 
-  }else{
-    stop("The variable to predict must be of type factor or character", call. = FALSE )
+  } else {
+    stop("The variable to predict must be of type factor or character", call. = FALSE)
   }
 }
 
-
 #' categorical.predictive.power
 #'
 #' @description Function that graphs the distribution of individuals and shows their category according to a categorical variable.
@@ -135,7 +165,7 @@ numerical.predictive.power <- function(data, predict.variable, variable.to.compa
 #'
 #' @import ggplot2
 #' @import dplyr
-#'
+#' @importFrom rlang .data
 #' @export
 #'
 #' @examples
@@ -145,47 +175,74 @@ numerical.predictive.power <- function(data, predict.variable, variable.to.compa
 #' cars$vs <- as.factor(cars$vs)
 #' categorical.predictive.power(cars,"vs","cyl")
 #'
-categorical.predictive.power <- function(data, predict.variable, variable.to.compare, ylab = "",
-                                        xlab = "", main = paste("Variable Distribution", variable.to.compare, 'according to', predict.variable), col = NA) {
+categorical.predictive.power <- function(
+    data, predict.variable, variable.to.compare,
+    ylab = "",
+    xlab = "",
+    main = paste("Variable Distribution", variable.to.compare, "according to", predict.variable),
+    col = NA
+) {
 
-  if(missing(predict.variable) | !(predict.variable %in% colnames(data))){
-    stop("predict.variable must be entered and be part of the table columns", call. = FALSE )
-  }
-  if(missing(variable.to.compare) | !(variable.to.compare %in% colnames(data)) |
-     !(is.factor(data[,variable.to.compare]) | is.character(data[,variable.to.compare])) ){
-    stop("variable.to.compare must be entered and be part of the categorical columns of the table", call. = FALSE )
+  if (missing(predict.variable) || !(predict.variable %in% colnames(data))) {
+    stop("predict.variable must be entered and be part of the table columns", call. = FALSE)
   }
 
-  if(is.character(data[,predict.variable]) | is.factor(data[,predict.variable])){
-    if(length(col) == 0 || is.na(col)){
-      col <- gg_color(length(unique(data[,predict.variable])))
-    }else{
-      col <- rep(col,length(unique(data[,predict.variable])))
+  if (missing(variable.to.compare) || !(variable.to.compare %in% colnames(data)) ||
+      !(is.factor(data[[variable.to.compare]]) || is.character(data[[variable.to.compare]]))) {
+    stop("variable.to.compare must be entered and be part of the categorical columns of the table", call. = FALSE)
+  }
+
+  if (is.character(data[[predict.variable]]) || is.factor(data[[predict.variable]])) {
+
+    if (length(col) == 0 || all(is.na(col))) {
+      col <- gg_color(length(unique(data[[predict.variable]])))
+    } else {
+      col <- rep(col, length(unique(data[[predict.variable]])))
     }
 
-    suppressWarnings(datos2 <- data |>
-      dplyr::group_by_(variable.to.compare, predict.variable) |>
-      dplyr::summarise(count = n()))
+    suppressWarnings(
+      datos2 <- data |>
+        dplyr::group_by(dplyr::across(dplyr::all_of(c(variable.to.compare, predict.variable)))) |>
+        dplyr::summarise(count = dplyr::n(), .groups = "drop")
+    )
 
-    if(variable.to.compare != predict.variable){
-      suppressWarnings(datos2 <-   datos2 |> dplyr::group_by_(variable.to.compare))
+    if (variable.to.compare != predict.variable) {
+      suppressWarnings(
+        datos2 <- datos2 |>
+          dplyr::group_by(dplyr::across(dplyr::all_of(variable.to.compare)))
+      )
     }
-    datos2 <- datos2 |> dplyr::mutate(prop = round(count/sum(count),4))
 
-    ggplot(data = datos2, mapping = aes_string(x = variable.to.compare, y = "prop", fill = predict.variable)) +
-      geom_col(position = "fill") +
-      geom_text(aes(label = paste0(round(prop * 100, 2), "% (", count, ")")), position = position_stack(vjust = .5), color = "white") +
-      scale_y_continuous(labels = function(x) return(paste0(x * 100, "%"))) +
-      labs(y =  xlab, x  = ylab, title = main) +
-      scale_fill_manual(values = col, name = predict.variable) +
-      theme(legend.position = "bottom")+
-      coord_flip()
+    datos2 <- datos2 |>
+      dplyr::mutate(prop = round(count / sum(count), 4)) |>
+      dplyr::ungroup()
 
-  }else{
-    stop("The variable to predict must be of type factor or character", call. = FALSE )
+    ggplot2::ggplot(
+      data = datos2,
+      mapping = ggplot2::aes(
+        x = .data[[variable.to.compare]],
+        y = prop,
+        fill = .data[[predict.variable]]
+      )
+    ) +
+      ggplot2::geom_col(position = "fill") +
+      ggplot2::geom_text(
+        ggplot2::aes(label = paste0(round(prop * 100, 2), "% (", count, ")")),
+        position = ggplot2::position_stack(vjust = 0.5),
+        color = "white"
+      ) +
+      ggplot2::scale_y_continuous(labels = function(x) paste0(x * 100, "%")) +
+      ggplot2::labs(y = xlab, x = ylab, title = main) +
+      ggplot2::scale_fill_manual(values = col, name = predict.variable) +
+      ggplot2::theme(legend.position = "bottom") +
+      ggplot2::coord_flip()
+
+  } else {
+    stop("The variable to predict must be of type factor or character", call. = FALSE)
   }
 }
 
+
 #' importance.plot
 #'
 #' @description Function that graphs the importance of the variables.
@@ -200,6 +257,7 @@ categorical.predictive.power <- function(data, predict.variable, variable.to.com
 #' @note With this function we can identify how important the variables are for the generation of a predictive model.
 #'
 #' @import ggplot2
+#' @importFrom rlang .data
 #' @importFrom stats reorder
 #' @importFrom gbm summary.gbm
 #' @importFrom xgboost xgb.importance
@@ -216,7 +274,7 @@ categorical.predictive.power <- function(data, predict.variable, variable.to.com
 #'testing <- data[-sam,]
 #'
 #'model <- train.adabag(formula = Species~.,data = training,minsplit = 2,
-#'  maxdepth = 30, mfinal = 10)
+#'  maxdepth = 20, mfinal = 10)
 #'importance.plot(model)
 #'
 
@@ -248,16 +306,19 @@ importance.plot <- function(model, col = "steelblue") {
 
   } else if ("gbm.prmdt" %in% class(model)) {
 
-    aux <- summary.gbm(model, plotit = FALSE)
+    aux <- gbm::summary.gbm(model, plotit = FALSE)
     df <- data.frame(x = aux$var, y = aux$rel.inf)
 
   } else {
-    stop("The model does not have this functionality.")
+    stop("The model does not have this functionality.", call. = FALSE)
   }
 
   df$y <- round(df$y, digits = 2)
 
-  ggplot2::ggplot(data = df, ggplot2::aes(x = reorder(x, .data$y), y = y)) +
+  ggplot2::ggplot(
+    data = df,
+    ggplot2::aes(x = stats::reorder(x, .data$y), y = y)
+  ) +
     ggplot2::geom_bar(stat = "identity", fill = col, width = 0.6) +
     ggplot2::theme_minimal() +
     ggplot2::labs(
@@ -268,4 +329,3 @@ importance.plot <- function(model, col = "steelblue") {
     ggplot2::coord_flip()
 }
 
-
